import unittest


def peak_memory_usage(func, *args, **kwargs):
    """
    Monitor the memory usage of a function and return the peak memory used, in MiB.
    """
    try:
        from memory_profiler import memory_usage  # type: ignore
    except ImportError:
        raise unittest.SkipTest("memory-profiler is not available")

    try:
        mem_usage = memory_usage((func, args, kwargs), interval=0.1, timeout=None)
    except MemoryError:
        return float("inf")
    peak_memory = max(mem_usage) - min(mem_usage)
    return peak_memory



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

import sys

sys.path.insert(0, "..")

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'lxml_html_clean'
copyright = '2020, lxml dev team'
author = 'lxml dev team'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = ['sphinx.ext.autodoc']

templates_path = ['_templates']
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

autodoc_default_options = {
    'ignore-module-all': True,
    'private-members': True,
    'inherited-members': True,
}

autodoc_member_order = 'groupwise'

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'sphinx_rtd_theme'
#html_static_path = ['_static']
